==> temporian-0.1.0-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: temporian/core/operators/calendar/minute.py <==
# Copyright 2021 Google LLC.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Calendar minute operator class and public API function definitions."""

from temporian.core import operator_lib
from temporian.core.data.node import Node
from temporian.core.operators.calendar.base import BaseCalendarOperator


class CalendarMinuteOperator(BaseCalendarOperator):
    @classmethod
    @property
    def operator_def_key(cls) -> str:
        return "CALENDAR_MINUTE"

    @classmethod
    @property
    def output_feature_name(cls) -> str:
        return "calendar_minute"


operator_lib.register_operator(CalendarMinuteOperator)


def calendar_minute(sampling: Node) -> Node:
    """Obtain the minute the timestamps in a node's sampling are in.

    Features in the input node are ignored, only the timestamps in
    `Node.sampling` are used and they must be unix timestamps
    (check  `Node.sampling.is_unix_timestamp`).

    Output feature contains numbers between
    0 and 59.

    Args:
        sampling: Node to get the minutes from.

    Returns:
        Single feature with the minute each timestamp in `sampling` belongs to.
    """
    return CalendarMinuteOperator(sampling).outputs["output"]

==> temporian-0.7.0-cp310-cp310-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: temporian/core/operators/calendar/minute.py <==
# Copyright 2021 Google LLC.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Calendar minute operator class and public API function definitions."""

from typing import Union
from temporian.core import operator_lib
from temporian.core.compilation import compile
from temporian.core.data.node import EventSetNode
from temporian.core.operators.calendar.base import (
    BaseCalendarOperator,
    timezone_to_utc_offset,
)
from temporian.core.typing import EventSetOrNode


class CalendarMinuteOperator(BaseCalendarOperator):
    @classmethod
    def operator_def_key(cls) -> str:
        return "CALENDAR_MINUTE"

    @classmethod
    def output_feature_name(cls) -> str:
        return "calendar_minute"


operator_lib.register_operator(CalendarMinuteOperator)


@compile
def calendar_minute(
    sampling: EventSetOrNode, tz: Union[str, float, int] = 0
) -> EventSetOrNode:
    assert isinstance(sampling, EventSetNode)
    utc_offset = timezone_to_utc_offset(tz)

    return CalendarMinuteOperator(sampling, utc_offset).outputs["output"]
